==> zio-aws-auditmanager_3-5.17.126.2-sources.jar: zio/aws/auditmanager/model/AssessmentMetadata.scala <==
package zio.aws.auditmanager.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.auditmanager.model.primitives.{
  AssessmentName,
  Timestamp,
  ComplianceType,
  UUID,
  AssessmentDescription
}
import java.time.Instant
import scala.jdk.CollectionConverters.*
final case class AssessmentMetadata(
    name: Option[AssessmentName] = None,
    id: Option[UUID] = None,
    description: Option[AssessmentDescription] = None,
    complianceType: Option[ComplianceType] = None,
    status: Option[zio.aws.auditmanager.model.AssessmentStatus] = None,
    assessmentReportsDestination: Option[
      zio.aws.auditmanager.model.AssessmentReportsDestination
    ] = None,
    scope: Option[zio.aws.auditmanager.model.Scope] = None,
    roles: Option[Iterable[zio.aws.auditmanager.model.Role]] = None,
    delegations: Option[Iterable[zio.aws.auditmanager.model.Delegation]] = None,
    creationTime: Option[Timestamp] = None,
    lastUpdated: Option[Timestamp] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.auditmanager.model.AssessmentMetadata = {
    import AssessmentMetadata.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.auditmanager.model.AssessmentMetadata
      .builder()
      .optionallyWith(
        name.map(value => AssessmentName.unwrap(value): java.lang.String)
      )(_.name)
      .optionallyWith(id.map(value => UUID.unwrap(value): java.lang.String))(
        _.id
      )
      .optionallyWith(
        description.map(value =>
          AssessmentDescription.unwrap(value): java.lang.String
        )
      )(_.description)
      .optionallyWith(
        complianceType.map(value =>
          ComplianceType.unwrap(value): java.lang.String
        )
      )(_.complianceType)
      .optionallyWith(status.map(value => value.unwrap))(_.status)
      .optionallyWith(
        assessmentReportsDestination.map(value => value.buildAwsValue())
      )(_.assessmentReportsDestination)
      .optionallyWith(scope.map(value => value.buildAwsValue()))(_.scope)
      .optionallyWith(
        roles.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.roles)
      .optionallyWith(
        delegations.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.delegations)
      .optionallyWith(
        creationTime.map(value => Timestamp.unwrap(value): Instant)
      )(_.creationTime)
      .optionallyWith(
        lastUpdated.map(value => Timestamp.unwrap(value): Instant)
      )(_.lastUpdated)
      .build()
  }
  def asReadOnly: zio.aws.auditmanager.model.AssessmentMetadata.ReadOnly =
    zio.aws.auditmanager.model.AssessmentMetadata.wrap(buildAwsValue())
}
object AssessmentMetadata {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.auditmanager.model.AssessmentMetadata
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.auditmanager.model.AssessmentMetadata =
      zio.aws.auditmanager.model.AssessmentMetadata(
        name.map(value => value),
        id.map(value => value),
        description.map(value => value),
        complianceType.map(value => value),
        status.map(value => value),
        assessmentReportsDestination.map(value => value.asEditable),
        scope.map(value => value.asEditable),
        roles.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        delegations.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        creationTime.map(value => value),
        lastUpdated.map(value => value)
      )
    def name: Option[AssessmentName]
    def id: Option[UUID]
    def description: Option[AssessmentDescription]
    def complianceType: Option[ComplianceType]
    def status: Option[zio.aws.auditmanager.model.AssessmentStatus]
    def assessmentReportsDestination: Option[
      zio.aws.auditmanager.model.AssessmentReportsDestination.ReadOnly
    ]
    def scope: Option[zio.aws.auditmanager.model.Scope.ReadOnly]
    def roles: Option[List[zio.aws.auditmanager.model.Role.ReadOnly]]
    def delegations
        : Option[List[zio.aws.auditmanager.model.Delegation.ReadOnly]]
    def creationTime: Option[Timestamp]
    def lastUpdated: Option[Timestamp]
    def getName: ZIO[Any, AwsError, AssessmentName] =
      AwsError.unwrapOptionField("name", name)
    def getId: ZIO[Any, AwsError, UUID] = AwsError.unwrapOptionField("id", id)
    def getDescription: ZIO[Any, AwsError, AssessmentDescription] =
      AwsError.unwrapOptionField("description", description)
    def getComplianceType: ZIO[Any, AwsError, ComplianceType] =
      AwsError.unwrapOptionField("complianceType", complianceType)
    def getStatus
        : ZIO[Any, AwsError, zio.aws.auditmanager.model.AssessmentStatus] =
      AwsError.unwrapOptionField("status", status)
    def getAssessmentReportsDestination: ZIO[
      Any,
      AwsError,
      zio.aws.auditmanager.model.AssessmentReportsDestination.ReadOnly
    ] = AwsError.unwrapOptionField(
      "assessmentReportsDestination",
      assessmentReportsDestination
    )
    def getScope
        : ZIO[Any, AwsError, zio.aws.auditmanager.model.Scope.ReadOnly] =
      AwsError.unwrapOptionField("scope", scope)
    def getRoles
        : ZIO[Any, AwsError, List[zio.aws.auditmanager.model.Role.ReadOnly]] =
      AwsError.unwrapOptionField("roles", roles)
    def getDelegations: ZIO[Any, AwsError, List[
      zio.aws.auditmanager.model.Delegation.ReadOnly
    ]] = AwsError.unwrapOptionField("delegations", delegations)
    def getCreationTime: ZIO[Any, AwsError, Timestamp] =
      AwsError.unwrapOptionField("creationTime", creationTime)
    def getLastUpdated: ZIO[Any, AwsError, Timestamp] =
      AwsError.unwrapOptionField("lastUpdated", lastUpdated)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.auditmanager.model.AssessmentMetadata
  ) extends zio.aws.auditmanager.model.AssessmentMetadata.ReadOnly {
    override val name: Option[AssessmentName] = scala
      .Option(impl.name())
      .map(value => zio.aws.auditmanager.model.primitives.AssessmentName(value))
    override val id: Option[UUID] = scala
      .Option(impl.id())
      .map(value => zio.aws.auditmanager.model.primitives.UUID(value))
    override val description: Option[AssessmentDescription] = scala
      .Option(impl.description())
      .map(value =>
        zio.aws.auditmanager.model.primitives.AssessmentDescription(value)
      )
    override val complianceType: Option[ComplianceType] = scala
      .Option(impl.complianceType())
      .map(value => zio.aws.auditmanager.model.primitives.ComplianceType(value))
    override val status: Option[zio.aws.auditmanager.model.AssessmentStatus] =
      scala
        .Option(impl.status())
        .map(value => zio.aws.auditmanager.model.AssessmentStatus.wrap(value))
    override val assessmentReportsDestination: Option[
      zio.aws.auditmanager.model.AssessmentReportsDestination.ReadOnly
    ] = scala
      .Option(impl.assessmentReportsDestination())
      .map(value =>
        zio.aws.auditmanager.model.AssessmentReportsDestination.wrap(value)
      )
    override val scope: Option[zio.aws.auditmanager.model.Scope.ReadOnly] =
      scala
        .Option(impl.scope())
        .map(value => zio.aws.auditmanager.model.Scope.wrap(value))
    override val roles: Option[List[zio.aws.auditmanager.model.Role.ReadOnly]] =
      scala
        .Option(impl.roles())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.auditmanager.model.Role.wrap(item)
          }.toList
        )
    override val delegations
        : Option[List[zio.aws.auditmanager.model.Delegation.ReadOnly]] = scala
      .Option(impl.delegations())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.auditmanager.model.Delegation.wrap(item)
        }.toList
      )
    override val creationTime: Option[Timestamp] = scala
      .Option(impl.creationTime())
      .map(value => zio.aws.auditmanager.model.primitives.Timestamp(value))
    override val lastUpdated: Option[Timestamp] = scala
      .Option(impl.lastUpdated())
      .map(value => zio.aws.auditmanager.model.primitives.Timestamp(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.auditmanager.model.AssessmentMetadata
  ): zio.aws.auditmanager.model.AssessmentMetadata.ReadOnly = new Wrapper(impl)
}

==> zio-aws-auditmanager_3-5.17.233.1-sources.jar: zio/aws/auditmanager/model/AssessmentMetadata.scala <==
package zio.aws.auditmanager.model
import java.time.Instant
import zio.prelude.data.Optional
import zio.aws.auditmanager.model.primitives.{
  AssessmentName,
  Timestamp,
  ComplianceType,
  UUID,
  AssessmentDescription
}
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import scala.jdk.CollectionConverters.*
final case class AssessmentMetadata(
    name: Optional[AssessmentName] = Optional.Absent,
    id: Optional[UUID] = Optional.Absent,
    description: Optional[AssessmentDescription] = Optional.Absent,
    complianceType: Optional[ComplianceType] = Optional.Absent,
    status: Optional[zio.aws.auditmanager.model.AssessmentStatus] =
      Optional.Absent,
    assessmentReportsDestination: Optional[
      zio.aws.auditmanager.model.AssessmentReportsDestination
    ] = Optional.Absent,
    scope: Optional[zio.aws.auditmanager.model.Scope] = Optional.Absent,
    roles: Optional[Iterable[zio.aws.auditmanager.model.Role]] =
      Optional.Absent,
    delegations: Optional[Iterable[zio.aws.auditmanager.model.Delegation]] =
      Optional.Absent,
    creationTime: Optional[Timestamp] = Optional.Absent,
    lastUpdated: Optional[Timestamp] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.auditmanager.model.AssessmentMetadata = {
    import AssessmentMetadata.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.auditmanager.model.AssessmentMetadata
      .builder()
      .optionallyWith(
        name.map(value => AssessmentName.unwrap(value): java.lang.String)
      )(_.name)
      .optionallyWith(id.map(value => UUID.unwrap(value): java.lang.String))(
        _.id
      )
      .optionallyWith(
        description.map(value =>
          AssessmentDescription.unwrap(value): java.lang.String
        )
      )(_.description)
      .optionallyWith(
        complianceType.map(value =>
          ComplianceType.unwrap(value): java.lang.String
        )
      )(_.complianceType)
      .optionallyWith(status.map(value => value.unwrap))(_.status)
      .optionallyWith(
        assessmentReportsDestination.map(value => value.buildAwsValue())
      )(_.assessmentReportsDestination)
      .optionallyWith(scope.map(value => value.buildAwsValue()))(_.scope)
      .optionallyWith(
        roles.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.roles)
      .optionallyWith(
        delegations.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.delegations)
      .optionallyWith(
        creationTime.map(value => Timestamp.unwrap(value): Instant)
      )(_.creationTime)
      .optionallyWith(
        lastUpdated.map(value => Timestamp.unwrap(value): Instant)
      )(_.lastUpdated)
      .build()
  }
  def asReadOnly: zio.aws.auditmanager.model.AssessmentMetadata.ReadOnly =
    zio.aws.auditmanager.model.AssessmentMetadata.wrap(buildAwsValue())
}
object AssessmentMetadata {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.auditmanager.model.AssessmentMetadata
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.auditmanager.model.AssessmentMetadata =
      zio.aws.auditmanager.model.AssessmentMetadata(
        name.map(value => value),
        id.map(value => value),
        description.map(value => value),
        complianceType.map(value => value),
        status.map(value => value),
        assessmentReportsDestination.map(value => value.asEditable),
        scope.map(value => value.asEditable),
        roles.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        delegations.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        creationTime.map(value => value),
        lastUpdated.map(value => value)
      )
    def name: Optional[AssessmentName]
    def id: Optional[UUID]
    def description: Optional[AssessmentDescription]
    def complianceType: Optional[ComplianceType]
    def status: Optional[zio.aws.auditmanager.model.AssessmentStatus]
    def assessmentReportsDestination: Optional[
      zio.aws.auditmanager.model.AssessmentReportsDestination.ReadOnly
    ]
    def scope: Optional[zio.aws.auditmanager.model.Scope.ReadOnly]
    def roles: Optional[List[zio.aws.auditmanager.model.Role.ReadOnly]]
    def delegations
        : Optional[List[zio.aws.auditmanager.model.Delegation.ReadOnly]]
    def creationTime: Optional[Timestamp]
    def lastUpdated: Optional[Timestamp]
    def getName: ZIO[Any, AwsError, AssessmentName] =
      AwsError.unwrapOptionField("name", name)
    def getId: ZIO[Any, AwsError, UUID] = AwsError.unwrapOptionField("id", id)
    def getDescription: ZIO[Any, AwsError, AssessmentDescription] =
      AwsError.unwrapOptionField("description", description)
    def getComplianceType: ZIO[Any, AwsError, ComplianceType] =
      AwsError.unwrapOptionField("complianceType", complianceType)
    def getStatus
        : ZIO[Any, AwsError, zio.aws.auditmanager.model.AssessmentStatus] =
      AwsError.unwrapOptionField("status", status)
    def getAssessmentReportsDestination: ZIO[
      Any,
      AwsError,
      zio.aws.auditmanager.model.AssessmentReportsDestination.ReadOnly
    ] = AwsError.unwrapOptionField(
      "assessmentReportsDestination",
      assessmentReportsDestination
    )
    def getScope
        : ZIO[Any, AwsError, zio.aws.auditmanager.model.Scope.ReadOnly] =
      AwsError.unwrapOptionField("scope", scope)
    def getRoles
        : ZIO[Any, AwsError, List[zio.aws.auditmanager.model.Role.ReadOnly]] =
      AwsError.unwrapOptionField("roles", roles)
    def getDelegations: ZIO[Any, AwsError, List[
      zio.aws.auditmanager.model.Delegation.ReadOnly
    ]] = AwsError.unwrapOptionField("delegations", delegations)
    def getCreationTime: ZIO[Any, AwsError, Timestamp] =
      AwsError.unwrapOptionField("creationTime", creationTime)
    def getLastUpdated: ZIO[Any, AwsError, Timestamp] =
      AwsError.unwrapOptionField("lastUpdated", lastUpdated)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.auditmanager.model.AssessmentMetadata
  ) extends zio.aws.auditmanager.model.AssessmentMetadata.ReadOnly {
    override val name: Optional[AssessmentName] = zio.aws.core.internal
      .optionalFromNullable(impl.name())
      .map(value => zio.aws.auditmanager.model.primitives.AssessmentName(value))
    override val id: Optional[UUID] = zio.aws.core.internal
      .optionalFromNullable(impl.id())
      .map(value => zio.aws.auditmanager.model.primitives.UUID(value))
    override val description: Optional[AssessmentDescription] =
      zio.aws.core.internal
        .optionalFromNullable(impl.description())
        .map(value =>
          zio.aws.auditmanager.model.primitives.AssessmentDescription(value)
        )
    override val complianceType: Optional[ComplianceType] =
      zio.aws.core.internal
        .optionalFromNullable(impl.complianceType())
        .map(value =>
          zio.aws.auditmanager.model.primitives.ComplianceType(value)
        )
    override val status: Optional[zio.aws.auditmanager.model.AssessmentStatus] =
      zio.aws.core.internal
        .optionalFromNullable(impl.status())
        .map(value => zio.aws.auditmanager.model.AssessmentStatus.wrap(value))
    override val assessmentReportsDestination: Optional[
      zio.aws.auditmanager.model.AssessmentReportsDestination.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.assessmentReportsDestination())
      .map(value =>
        zio.aws.auditmanager.model.AssessmentReportsDestination.wrap(value)
      )
    override val scope: Optional[zio.aws.auditmanager.model.Scope.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.scope())
        .map(value => zio.aws.auditmanager.model.Scope.wrap(value))
    override val roles
        : Optional[List[zio.aws.auditmanager.model.Role.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.roles())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.auditmanager.model.Role.wrap(item)
          }.toList
        )
    override val delegations
        : Optional[List[zio.aws.auditmanager.model.Delegation.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.delegations())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.auditmanager.model.Delegation.wrap(item)
          }.toList
        )
    override val creationTime: Optional[Timestamp] = zio.aws.core.internal
      .optionalFromNullable(impl.creationTime())
      .map(value => zio.aws.auditmanager.model.primitives.Timestamp(value))
    override val lastUpdated: Optional[Timestamp] = zio.aws.core.internal
      .optionalFromNullable(impl.lastUpdated())
      .map(value => zio.aws.auditmanager.model.primitives.Timestamp(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.auditmanager.model.AssessmentMetadata
  ): zio.aws.auditmanager.model.AssessmentMetadata.ReadOnly = new Wrapper(impl)
}
